@@ -1,7 +1,7 @@
 from collections import defaultdict
 import logging
 import json
-from typing import Dict, Generator, List, NamedTuple, Optional, Text, Tuple
+from typing import DefaultDict, Dict, Generator, List, NamedTuple, Optional, Text, Tuple
 
 from rasa.core.featurizers.tracker_featurizers import MaxHistoryTrackerFeaturizer
 from rasa.shared.core.constants import (
@@ -38,7 +38,7 @@ class StoryConflict:
 
         self._sliced_states = sliced_states
         # A list of actions that all follow from the same state.
-        self._conflicting_actions: defaultdict[Text, List[Text]] = defaultdict(
+        self._conflicting_actions: DefaultDict[Text, List[Text]] = defaultdict(
             list
         )  # {"action": ["story_1", ...], ...}
 
@@ -181,7 +181,7 @@ def _find_conflicting_states(
     domain: Domain,
     max_history: Optional[int],
     tokenizer: Optional[Tokenizer] = None,
-) -> Dict[int, Optional[List[Text]]]:
+) -> Dict[int, List[int]]:
     """Identifies all states from which different actions follow.
 
     Args:
@@ -196,7 +196,7 @@ def _find_conflicting_states(
     """
     # Create a 'state -> list of actions' dict, where the state is
     # represented by its hash
-    state_action_mapping: defaultdict[int, List[int]] = defaultdict(list)
+    state_action_mapping: DefaultDict[int, List[int]] = defaultdict(list)
 
     for element in _sliced_states_iterator(trackers, domain, max_history, tokenizer):
         hashed_state = element.sliced_states_hash
@@ -238,7 +238,7 @@ def _build_conflicts_from_states(
     trackers: List[TrackerWithCachedStates],
     domain: Domain,
     max_history: Optional[int],
-    conflicting_state_action_mapping: Dict[int, Optional[List[Text]]],
+    conflicting_state_action_mapping: Dict[int, List[int]],
     tokenizer: Optional[Tokenizer] = None,
 ) -> List["StoryConflict"]:
     """Builds a list of `StoryConflict` objects for each given conflict.
