@@ -242,6 +242,7 @@ def _get_parameter_information(
 
     type_hints = _get_type_hints(uses, fn)
     return_type = type_hints.pop("return", inspect.Parameter.empty)
+    type_hints.pop("cls", None)
 
     params = inspect.signature(fn).parameters
 
@@ -442,7 +443,7 @@ def _validate_needs(
         if not has_kwargs and required_type is not None:
             parent = None
             if _is_placeholder_input(parent_name):
-                parent_return_type = RESERVED_PLACEHOLDERS[parent_name]
+                parent_return_type: TypeAnnotation = RESERVED_PLACEHOLDERS[parent_name]
             else:
                 parent = graph.nodes[parent_name]
                 _, parent_return_type = _get_parameter_information(
