@@ -358,8 +358,7 @@ class LanguageModelFeaturizer(DenseFeaturizer, GraphComponent):
             )
             attention_mask.append(padded_sequence)
 
-        attention_mask = np.array(attention_mask).astype(np.float32)
-        return attention_mask
+        return np.array(attention_mask).astype(np.float32)
 
     def _extract_sequence_lengths(
         self, batch_token_ids: List[List[int]]
@@ -654,9 +653,8 @@ class LanguageModelFeaturizer(DenseFeaturizer, GraphComponent):
         sequence_final_embeddings = []
         for embeddings, tokens in zip(sequence_embeddings, batch_tokens):
             sequence_final_embeddings.append(embeddings[: len(tokens)])
-        sequence_final_embeddings = np.array(sequence_final_embeddings)
 
-        return sentence_embeddings, sequence_final_embeddings
+        return sentence_embeddings, np.array(sequence_final_embeddings)
 
     def _get_docs_for_batch(
         self,
