@@ -83,8 +83,9 @@ class MultiHeadAttention(tf.keras.layers.Layer):
 
     def _create_relative_embeddings(self) -> None:
         """Create relative embeddings."""
-
-        relative_embedding_shape = None
+        relative_embedding_shape: Optional[
+            Union[Tuple[int, int], Tuple[int, int, int]]
+        ] = None
         self.key_relative_embeddings = None
         self.value_relative_embeddings = None
 
